pub enum ErrorKind {
DecodingError(DecodingErrorKind),
FragmentError(FragmentErrorKind),
PacketError(PacketErrorKind),
IOError(Error),
ReceivedDataToShort,
ProtocolVersionMismatch,
CouldNotReadHeader(String),
}Expand description
Enum with all possible errors that could occur while processing packets.
Variants
DecodingError(DecodingErrorKind)
Error in decoding the packet
FragmentError(FragmentErrorKind)
Error relating to receiving or parsing a fragment
PacketError(PacketErrorKind)
Error relating to receiving or parsing a packet
IOError(Error)
Wrapper around a std io::Error
ReceivedDataToShort
Did not receive enough data
ProtocolVersionMismatch
Protocol versions did not match
CouldNotReadHeader(String)
Expected header but could not be read from buffer.