FragmentErrorKind

Enum FragmentErrorKind 

pub enum FragmentErrorKind {
    PacketHeaderNotFound,
    ExceededMaxFragments,
    AlreadyProcessedFragment,
    FragmentWithUnevenNumberOfFragments,
    CouldNotFindFragmentById,
    MultipleAckHeaders,
    MissingAckHeader,
}
Errors that could occur with constructing/parsing fragment contents

Variants



PacketHeaderNotFound

PacketHeader was not found in the packet



ExceededMaxFragments

Max number of allowed fragments has been exceeded



AlreadyProcessedFragment

This fragment was already processed



FragmentWithUnevenNumberOfFragments

Attempted to fragment with an incorrect number of fragments



CouldNotFindFragmentById

Fragment we expected to be able to find we couldn’t



MultipleAckHeaders

Multiple ack headers sent with these fragments



MissingAckHeader

Ack header is missing from a finished set of fragments