pub enum PacketErrorKind {
ExceededMaxPacketSize,
PacketCannotBeFragmented,
MtuTooSmall,
PayloadTooLargeToFragment,
}Expand description
Errors that could occur while parsing packet contents
Variants
ExceededMaxPacketSize
The maximal allowed size of the packet was exceeded
PacketCannotBeFragmented
Only PacketType::Packet can be fragmented
MtuTooSmall
MTU is too small to accommodate packet headers and minimum payload
PayloadTooLargeToFragment
Packet payload too large to fragment with current MTU settings